@@ -14,7 +14,7 @@ our @EXPORT_OK = qw(email);
 
 use Moo;
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 my %headers = map {
     my $name = lc $_;
@@ -1089,7 +1089,7 @@ Emailesque - Lightweight To-The-Point Email
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -1116,13 +1116,13 @@ The following is an example of the object-oriented interface:
 
     use Emailesque;
 
-    my $email = Emailesque->new({
+    my $email = Emailesque->new(
         to      => '...',
         from    => '...',
         subject => '...',
         message => '...',
         files   => [ '/path/to/file/1', '/path/to/file/2' ],
-    });
+    );
 
     my $result = $email->send;
 
@@ -1138,13 +1138,13 @@ following is an example of that:
 
     use Emailesque;
 
-    my $email = Emailesque->new({
+    my $email = Emailesque->new(
         from     => '...',
         subject  => '...',
         x_mailer => "MyApp-Newletter 0.019876",
         x_url    => "https://mail.to/u/123/welcome",
         type     => 'text',
-    });
+    );
 
     for my $user (@users) {
         my $message = msg_generation $user;
